@@ -6,17 +6,23 @@ from django.db import models
 
 
 class Migration(SchemaMigration):
-    depends_on = (
-        ("kitchen_sink", "0003_auto__add_field_inline_icnt"),
-    )
-    
+
     def forwards(self, orm):
+        # Adding model 'FileFormat'
+        db.create_table(u'blog_fileformat', (
+            (u'id', self.gf('django.db.models.fields.AutoField')(primary_key=True)),
+            ('title', self.gf('django.db.models.fields.CharField')(max_length=255)),
+            ('ext', self.gf('django.db.models.fields.SlugField')(max_length=10)),
+        ))
+        db.send_create_signal(u'blog', ['FileFormat'])
+
         # Adding model 'Blog'
         db.create_table(u'blog_blog', (
             (u'id', self.gf('django.db.models.fields.AutoField')(primary_key=True)),
             ('title', self.gf('django.db.models.fields.CharField')(max_length=255)),
             ('slug', self.gf('django.db.models.fields.SlugField')(unique=True, max_length=200)),
             ('description', self.gf('django.db.models.fields.TextField')()),
+            ('podcast', self.gf('django.db.models.fields.BooleanField')(default=False)),
         ))
         db.send_create_signal(u'blog', ['Blog'])
 
@@ -52,7 +58,6 @@ class Migration(SchemaMigration):
             ('blog', self.gf('django.db.models.fields.related.ForeignKey')(to=orm['blog.Blog'])),
             ('title', self.gf('django.db.models.fields.CharField')(max_length=255)),
             ('slug', self.gf('django.db.models.fields.SlugField')(unique=True, max_length=200)),
-            ('author', self.gf('django.db.models.fields.related.ForeignKey')(to=orm['kitchen_sink.Author'])),
             ('publish', self.gf('django.db.models.fields.DateTimeField')()),
             ('body', self.gf('django.db.models.fields.TextField')()),
             ('image', self.gf('django.db.models.fields.related.ForeignKey')(to=orm['kitchen_sink.Image'], null=True, blank=True)),
@@ -60,6 +65,15 @@ class Migration(SchemaMigration):
         ))
         db.send_create_signal(u'blog', ['Post'])
 
+        # Adding M2M table for field authors on 'Post'
+        m2m_table_name = db.shorten_name(u'blog_post_authors')
+        db.create_table(m2m_table_name, (
+            ('id', models.AutoField(verbose_name='ID', primary_key=True, auto_created=True)),
+            ('post', models.ForeignKey(orm[u'blog.post'], null=False)),
+            ('author', models.ForeignKey(orm[u'kitchen_sink.author'], null=False))
+        ))
+        db.create_unique(m2m_table_name, ['post_id', 'author_id'])
+
         # Adding M2M table for field categories on 'Post'
         m2m_table_name = db.shorten_name(u'blog_post_categories')
         db.create_table(m2m_table_name, (
@@ -69,8 +83,20 @@ class Migration(SchemaMigration):
         ))
         db.create_unique(m2m_table_name, ['post_id', 'category_id'])
 
+        # Adding model 'MediaFile'
+        db.create_table(u'blog_mediafile', (
+            (u'id', self.gf('django.db.models.fields.AutoField')(primary_key=True)),
+            ('file', self.gf('django.db.models.fields.files.FileField')(max_length=100)),
+            ('ext', self.gf('django.db.models.fields.related.ForeignKey')(to=orm['blog.FileFormat'])),
+            ('post', self.gf('django.db.models.fields.related.ForeignKey')(to=orm['blog.Post'])),
+        ))
+        db.send_create_signal(u'blog', ['MediaFile'])
+
 
     def backwards(self, orm):
+        # Deleting model 'FileFormat'
+        db.delete_table(u'blog_fileformat')
+
         # Deleting model 'Blog'
         db.delete_table(u'blog_blog')
 
@@ -86,9 +112,15 @@ class Migration(SchemaMigration):
         # Deleting model 'Post'
         db.delete_table(u'blog_post')
 
+        # Removing M2M table for field authors on 'Post'
+        db.delete_table(db.shorten_name(u'blog_post_authors'))
+
         # Removing M2M table for field categories on 'Post'
         db.delete_table(db.shorten_name(u'blog_post_categories'))
 
+        # Deleting model 'MediaFile'
+        db.delete_table(u'blog_mediafile')
+
 
     models = {
         u'blog.blog': {
@@ -96,6 +128,7 @@ class Migration(SchemaMigration):
             'authors': ('django.db.models.fields.related.ManyToManyField', [], {'symmetrical': 'False', 'to': u"orm['kitchen_sink.Author']", 'null': 'True', 'blank': 'True'}),
             'description': ('django.db.models.fields.TextField', [], {}),
             u'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
+            'podcast': ('django.db.models.fields.BooleanField', [], {'default': 'False'}),
             'sites': ('django.db.models.fields.related.ManyToManyField', [], {'symmetrical': 'False', 'to': u"orm['sites.Site']", 'null': 'True', 'blank': 'True'}),
             'slug': ('django.db.models.fields.SlugField', [], {'unique': 'True', 'max_length': '200'}),
             'title': ('django.db.models.fields.CharField', [], {'max_length': '255'})
@@ -106,9 +139,22 @@ class Migration(SchemaMigration):
             'slug': ('django.db.models.fields.SlugField', [], {'unique': 'True', 'max_length': '200'}),
             'title': ('django.db.models.fields.CharField', [], {'max_length': '100'})
         },
+        u'blog.fileformat': {
+            'Meta': {'ordering': "('title',)", 'object_name': 'FileFormat'},
+            'ext': ('django.db.models.fields.SlugField', [], {'max_length': '10'}),
+            u'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
+            'title': ('django.db.models.fields.CharField', [], {'max_length': '255'})
+        },
+        u'blog.mediafile': {
+            'Meta': {'object_name': 'MediaFile'},
+            'ext': ('django.db.models.fields.related.ForeignKey', [], {'to': u"orm['blog.FileFormat']"}),
+            'file': ('django.db.models.fields.files.FileField', [], {'max_length': '100'}),
+            u'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
+            'post': ('django.db.models.fields.related.ForeignKey', [], {'to': u"orm['blog.Post']"})
+        },
         u'blog.post': {
             'Meta': {'ordering': "('-publish',)", 'object_name': 'Post'},
-            'author': ('django.db.models.fields.related.ForeignKey', [], {'to': u"orm['kitchen_sink.Author']"}),
+            'authors': ('django.db.models.fields.related.ManyToManyField', [], {'symmetrical': 'False', 'to': u"orm['kitchen_sink.Author']", 'null': 'True', 'blank': 'True'}),
             'blog': ('django.db.models.fields.related.ForeignKey', [], {'to': u"orm['blog.Blog']"}),
             'body': ('django.db.models.fields.TextField', [], {}),
             'categories': ('django.db.models.fields.related.ManyToManyField', [], {'symmetrical': 'False', 'to': u"orm['blog.Category']", 'null': 'True', 'blank': 'True'}),
